# gtars
This is a python wrapper around the `gtars` crate. It provides an easy interface for using `gtars` in python. It is currently in early development, and as such, it does not have a lot of functionality yet, but new tools are being worked on right now.

## Installation
You can get `gtars` from PyPI:
```bash
pip install gtars
```

## Usage
Import the package, and use the tools:
```python
import gtars as gt

gt.prune_universe(...)
```
## Developer docs
Write the develop docs here...